==> lxqt-policykit-1.0.0.tar.xz: lxqt-policykit-1.0.0/translations/lxqt-policykit-agent_vi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="vi">
<context>
    <name>LXQtPolicykit::PolicykitAgent</name>
    <message>
        <location filename="../src/policykitagent.cpp" line="75"/>
        <location filename="../src/policykitagent.cpp" line="169"/>
        <source>PolicyKit Information</source>
        <translation>Thông tin PolicyKIt</translation>
    </message>
    <message>
        <location filename="../src/policykitagent.cpp" line="75"/>
        <source>Another authentication is in progress. Please try again later.</source>
        <translation>Một xác thực khác đang được thực thi. Vui lòng thử lại sau.</translation>
    </message>
    <message>
        <location filename="../src/policykitagent.cpp" line="145"/>
        <source>Authorization Failed</source>
        <translation>Xác thực Thất bại</translation>
    </message>
    <message>
        <location filename="../src/policykitagent.cpp" line="145"/>
        <source>Authorization failed for some reason</source>
        <translation>Xác thực thất bại vì nguyên nhân nào đó</translation>
    </message>
    <message>
        <location filename="../src/policykitagent.cpp" line="162"/>
        <source>PolicyKit Error</source>
        <translation>Lỗi PolicyKit</translation>
    </message>
</context>
<context>
    <name>PolicykitAgentGUI</name>
    <message>
        <location filename="../src/policykitagentgui.ui" line="14"/>
        <source>Authentication Required</source>
        <translation>Yêu cầu Xác thực</translation>
    </message>
    <message>
        <location filename="../src/policykitagentgui.ui" line="55"/>
        <source>Identity:</source>
        <translation>Nhận dạng:</translation>
    </message>
    <message>
        <location filename="../src/policykitagentgui.ui" line="65"/>
        <source>Password:</source>
        <translation>Mật khẩu:</translation>
    </message>
</context>
</TS>

==> lxqt-policykit_1.1.0.orig.tar.xz: lxqt-policykit-1.1.0/translations/lxqt-policykit-agent_vi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="vi">
<context>
    <name>LXQtPolicykit::PolicykitAgent</name>
    <message>
        <location filename="../src/policykitagent.cpp" line="81"/>
        <location filename="../src/policykitagent.cpp" line="174"/>
        <source>PolicyKit Information</source>
        <translation>Thông tin PolicyKIt</translation>
    </message>
    <message>
        <location filename="../src/policykitagent.cpp" line="81"/>
        <source>Another authentication is in progress. Please try again later.</source>
        <translation>Một xác thực khác đang được thực thi. Vui lòng thử lại sau.</translation>
    </message>
    <message>
        <location filename="../src/policykitagent.cpp" line="151"/>
        <source>Authorization Failed</source>
        <translation>Xác thực Thất bại</translation>
    </message>
    <message>
        <location filename="../src/policykitagent.cpp" line="151"/>
        <source>Authorization failed for some reason</source>
        <translation>Xác thực thất bại vì nguyên nhân nào đó</translation>
    </message>
    <message>
        <location filename="../src/policykitagent.cpp" line="167"/>
        <source>PolicyKit Error</source>
        <translation>Lỗi PolicyKit</translation>
    </message>
</context>
<context>
    <name>PolicykitAgentGUI</name>
    <message>
        <location filename="../src/policykitagentgui.ui" line="14"/>
        <location filename="../build/lxqt-policykit-agent_autogen/include/ui_policykitagentgui.h" line="100"/>
        <source>Authentication Required</source>
        <translation>Yêu cầu Xác thực</translation>
    </message>
    <message>
        <location filename="../src/policykitagentgui.ui" line="55"/>
        <location filename="../build/lxqt-policykit-agent_autogen/include/ui_policykitagentgui.h" line="101"/>
        <source>Identity:</source>
        <translation>Nhận dạng:</translation>
    </message>
    <message>
        <location filename="../src/policykitagentgui.ui" line="65"/>
        <location filename="../build/lxqt-policykit-agent_autogen/include/ui_policykitagentgui.h" line="102"/>
        <source>Password:</source>
        <translation>Mật khẩu:</translation>
    </message>
</context>
</TS>
